@@ -1,5 +1,5 @@
 /* gtktools.h  -  The GNU Privacy Assistant
- *      Copyright (C) 2000 Free Software Foundation, Inc.
+ *      Copyright (C) 2000, 2001 G-N-U GmbH.
  *
  * This file is part of GPA
  *
@@ -27,12 +27,14 @@ extern GtkWidget *gpa_widget_hjustified_new (GtkWidget * widget,
 extern GtkWidget *gpa_button_new (GtkAccelGroup * accelGroup,
 				  gchar * labelText);
 extern GtkWidget *gpa_xpm_label_box( GtkWidget *parent,
-					gchar     **xpm,
-					gchar     *label_text,
-					GtkWidget * button,
-					GtkAccelGroup * accelGroup);
+				     const char *xpm_name,
+                                     gchar     *label_text,
+                                     GtkWidget * button,
+                                     GtkAccelGroup * accelGroup);
 extern GtkWidget *gpa_buttonCancel_new (GtkAccelGroup * accelGroup,
 					gchar * labelText, gpointer * param);
+extern GtkWidget *gpa_button_cancel_new (GtkAccelGroup * accel, gchar * label,
+					 GtkSignalFunc func, gpointer param);
 extern GtkWidget *gpa_check_button_new (GtkAccelGroup * accelGroup,
 					gchar * labelText);
 extern GtkWidget *gpa_radio_button_new (GtkAccelGroup * accelGroup,
@@ -46,10 +48,16 @@ extern GtkWidget *gpa_toggle_button_new (GtkAccelGroup * accelGroup,
 extern void gpa_connect_by_accelerator (GtkLabel * label, GtkWidget * widget,
 					GtkAccelGroup * accelGroup,
 					gchar * labelText);
-extern void gpa_widget_set_centered (GtkWidget * widget, GtkWidget * parent);
-extern void gpa_widget_show (GtkWidget * widget, GtkWidget * parent,
-			     gchar * tip);
+void gpa_button_set_text (GtkWidget * button, gchar * text, GtkAccelGroup *);
+extern void gpa_window_show_centered (GtkWidget * widget, GtkWidget * parent);
 extern void gpa_window_error (gchar * message, GtkWidget * messenger);
 extern void gpa_window_message (gchar * message, GtkWidget * messenger);
+gchar * gpa_message_box_run (GtkWidget * parent, const gchar * title,
+			     const gchar * message,
+			     const gchar ** buttons);
 extern void gpa_window_passphrase (GtkWidget * messenger, GtkSignalFunc func,
 				   gchar * tip, gpointer data);
+gchar * gpa_get_save_file_name (GtkWidget * parent, const gchar * title,
+				const gchar * directory);
+gchar * gpa_get_load_file_name (GtkWidget * parent, const gchar * title,
+				const gchar * directory);
