@@ -1,5 +1,5 @@
 /* keysmenu.h  -  The GNU Privacy Assistant
- *      Copyright (C) 2000 Free Software Foundation, Inc.
+ *      Copyright (C) 2000, 2001 G-N-U GmbH.
  *
  * This file is part of GPA
  *
@@ -24,9 +24,7 @@ extern void keys_unselectKey (GtkWidget * clistKeys, gint row, gint column,
 			      GdkEventButton * event, gpointer param);
 extern GtkWidget *gpa_tableKey_new (GpapaKey * key, GtkWidget * window);
 
-extern void keys_openPublic (void);
 extern void keys_openSecret (void);
-extern void keys_generateKey (void);
 extern void keys_generateRevocation (void);
 extern void keys_import (void);
 extern void keys_importOwnertrust (void);
